--[[
    Simple addon to disable the login system spam.

    Made by Nezoia <thedeathart@gmail.com>
    Also try visit my website, http://www.twilight-wizard.net
]]--

--- The frame name used for the addon.
local _addon = "nDisableLoginSpam";

--- List of filters, please note the 'spam' is case sensitive.
local _spam = {}

---
--- German.
---
if (locale == "deDE") then
    _spam["nWelcomeLine"]    = "Willkommen af den europischen World of Warcraft Realms!."
    _spam["nGMSpamLine1"]    = "Wenn ihr ein Ticket geschrieben habt, beachtet bitte, dass ihr auf das"
    _spam["nGMSpamLine2"]    = "Fenster \"GM-Chat\" klicken msst, welches in der rechten oberen Ecke eures"
    _spam["nGMSpamLine3"]    = "Bildschirms erscheint, sobald einer unserer Game Master euch kontaktiert."
---
--- English (default).
---
else
    _spam["nWelcomeLine"]    = "Welcome to the European Realms of World of Warcraft."
    _spam["nGMSpamLine1"]    = "If you have submitted an in-game help petition please note that you"
    _spam["nGMSpamLine2"]    = "will need to click on the 'GM Chat Request' that will appear in the"
    _spam["nGMSpamLine3"]    = "right-hand corner of the game in order to open the conversation"
    _spam["nGMSpamLine4"]    = "with a Game Master."
end


---
--- Filters specified system messages from the chat.
---
local function LoginSpamFilter(message)
    --- Iterate over the different spam messages.
    for key, value in pairs(_spam) do
        --- If we find a match, filter it from the text.
        if message == value then
            return true
        end
    end

    return false, message
end

---
--- Add the SYSTEM chat filter to the message default message filter.
---
local function nDisableLoginSpam_OnEvent(self, event)
    ChatFrame_AddMessageEventFilter("CHAT_MSG_SYSTEM", LoginSpamFilter)
end

---
--- Loads the addon
---
local function nDisableLoginSpam()
    local frame = CreateFrame("Frame", _addon);
    frame:SetScript("OnEvent", nDisableLoginSpam_OnEvent);
    frame:RegisterEvent("PLAYER_LOGIN")
end

nDisableLoginSpam()